@@ -72,6 +72,8 @@ class BasePo(object):
                 raise RuntimeError(f"根据selector: {selector}，在页面没有找到对应的元素")
         except (PlaywrightTimeoutError,):
             raise PlaywrightTimeoutError(f"元素 '{selector}' 未在 {timeout} 秒内找到")
+        except (RuntimeError, ):
+            raise
         except Exception as e:
             raise RuntimeError(f"检查元素时发生错误: {str(e)}")
 
@@ -93,5 +95,7 @@ class BasePo(object):
                 raise RuntimeError(f"根据selector: {selector}，在页面Locator对象中没有查找对应的子Locator对象")
         except (PlaywrightTimeoutError,):
             raise PlaywrightTimeoutError(f"元素 '{selector}' 未在 {timeout} 秒内找到")
+        except (RuntimeError, ):
+            raise
         except Exception as e:
             raise RuntimeError(f"检查元素时发生错误: {str(e)}")
